@@ -1,7 +1,6 @@
 use async_trait::async_trait;
 use k8s_openapi::{api::apps::v1::DaemonSet, chrono::Utc};
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -75,7 +74,7 @@ pub struct DaemonSetResource {}
 
 #[async_trait]
 impl AppResource for DaemonSetResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       DAEMON_SETS_TITLE,
       block,
@@ -96,7 +95,7 @@ impl AppResource for DaemonSetResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, DAEMON_SETS_TITLE, "", app.data.daemon_sets.items.len());
 
   draw_resource_block(
