@@ -4,7 +4,6 @@ use k8s_openapi::{
   chrono::Utc,
 };
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
@@ -168,7 +167,7 @@ pub struct IngressResource {}
 
 #[async_trait]
 impl AppResource for IngressResource {
-  fn render<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  fn render(block: ActiveBlock, f: &mut Frame<'_>, app: &mut App, area: Rect) {
     draw_resource_tab!(
       INGRESS_TITLE,
       block,
@@ -189,7 +188,7 @@ impl AppResource for IngressResource {
   }
 }
 
-fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+fn draw_block(f: &mut Frame<'_>, app: &mut App, area: Rect) {
   let title = get_resource_title(app, INGRESS_TITLE, "", app.data.ingress.items.len());
 
   draw_resource_block(
