@@ -2,7 +2,6 @@ use std::{collections::BTreeMap, rc::Rc, sync::OnceLock};
 
 use glob_match::glob_match;
 use ratatui::{
-  backend::Backend,
   layout::{Constraint, Direction, Layout, Rect},
   style::{Color, Modifier, Style},
   symbols,
@@ -34,8 +33,10 @@ pub const COLOR_GREEN: Color = Color::Rgb(72, 213, 150);
 pub const COLOR_RED: Color = Color::Rgb(249, 167, 164);
 pub const COLOR_ORANGE: Color = Color::Rgb(255, 170, 66);
 pub const COLOR_WHITE: Color = Color::Rgb(255, 255, 255);
+pub const COLOR_MAGENTA: Color = Color::Rgb(199, 146, 234);
+pub const COLOR_DARK_GRAY: Color = Color::Rgb(50, 50, 50);
 // light theme colors
-pub const COLOR_MAGENTA: Color = Color::Rgb(139, 0, 139);
+pub const COLOR_MAGENTA_DARK: Color = Color::Rgb(153, 26, 237);
 pub const COLOR_GRAY: Color = Color::Rgb(91, 87, 87);
 pub const COLOR_BLUE: Color = Color::Rgb(0, 82, 163);
 pub const COLOR_GREEN_DARK: Color = Color::Rgb(20, 97, 73);
@@ -85,6 +86,7 @@ fn get_yaml_themes() -> &'static YamlThemes {
 #[derive(Debug, PartialEq, Eq, Hash, PartialOrd, Ord)]
 pub enum Styles {
   Default,
+  Header,
   Logo,
   Failure,
   Warning,
@@ -99,12 +101,13 @@ pub fn theme_styles(light: bool) -> BTreeMap<Styles, Style> {
   if light {
     BTreeMap::from([
       (Styles::Default, Style::default().fg(COLOR_GRAY)),
+      (Styles::Header, Style::default().fg(COLOR_DARK_GRAY)),
       (Styles::Logo, Style::default().fg(COLOR_GREEN_DARK)),
       (Styles::Failure, Style::default().fg(COLOR_RED_DARK)),
       (Styles::Warning, Style::default().fg(COLOR_ORANGE_DARK)),
       (Styles::Success, Style::default().fg(COLOR_GREEN_DARK)),
       (Styles::Primary, Style::default().fg(COLOR_BLUE)),
-      (Styles::Secondary, Style::default().fg(COLOR_MAGENTA)),
+      (Styles::Secondary, Style::default().fg(COLOR_MAGENTA_DARK)),
       (Styles::Help, Style::default().fg(COLOR_BLUE)),
       (
         Styles::Background,
@@ -114,6 +117,7 @@ pub fn theme_styles(light: bool) -> BTreeMap<Styles, Style> {
   } else {
     BTreeMap::from([
       (Styles::Default, Style::default().fg(COLOR_WHITE)),
+      (Styles::Header, Style::default().fg(COLOR_DARK_GRAY)),
       (Styles::Logo, Style::default().fg(COLOR_GREEN)),
       (Styles::Failure, Style::default().fg(COLOR_RED)),
       (Styles::Warning, Style::default().fg(COLOR_ORANGE)),
@@ -133,13 +137,12 @@ pub fn title_style(txt: &str) -> Span<'_> {
   Span::styled(txt, style_bold())
 }
 
-pub fn title_style_logo(txt: &str, light: bool) -> Span<'_> {
-  Span::styled(
-    txt,
-    style_logo(light)
-      .add_modifier(Modifier::BOLD)
-      .add_modifier(Modifier::ITALIC),
-  )
+pub fn style_header_text(light: bool) -> Style {
+  *theme_styles(light).get(&Styles::Header).unwrap()
+}
+
+pub fn style_header() -> Style {
+  Style::default().bg(COLOR_MAGENTA)
 }
 
 pub fn style_bold() -> Style {
@@ -305,13 +308,7 @@ pub fn centered_rect(width: u16, height: u16, r: Rect) -> Rect {
     .split(popup_layout[1])[1]
 }
 
-pub fn loading<B: Backend>(
-  f: &mut Frame<'_, B>,
-  block: Block<'_>,
-  area: Rect,
-  is_loading: bool,
-  light: bool,
-) {
+pub fn loading(f: &mut Frame<'_>, block: Block<'_>, area: Rect, is_loading: bool, light: bool) {
   if is_loading {
     let text = "\n\n Loading ...\n\n".to_owned();
     let mut text = Text::from(text);
@@ -366,12 +363,7 @@ pub struct ResourceTableProps<'a, T> {
   pub column_widths: Vec<Constraint>,
 }
 /// common for all resources
-pub fn draw_describe_block<B: Backend>(
-  f: &mut Frame<'_, B>,
-  app: &App,
-  area: Rect,
-  title: Line<'_>,
-) {
+pub fn draw_describe_block(f: &mut Frame<'_>, app: &App, area: Rect, title: Line<'_>) {
   let block = layout_block_top_border(title);
 
   let txt = &app.data.describe_out.get_txt();
@@ -390,7 +382,7 @@ pub fn draw_describe_block<B: Backend>(
 }
 
 /// common for all resources
-pub fn draw_yaml_block<B: Backend>(f: &mut Frame<'_, B>, app: &App, area: Rect, title: Line<'_>) {
+pub fn draw_yaml_block(f: &mut Frame<'_>, app: &App, area: Rect, title: Line<'_>) {
   let block = layout_block_top_border(title);
 
   let txt = &app.data.describe_out.get_txt();
@@ -411,7 +403,7 @@ pub fn draw_yaml_block<B: Backend>(f: &mut Frame<'_, B>, app: &App, area: Rect,
           .into_iter()
           .filter_map(|segment| syntect_tui::into_span(segment).ok())
           .collect();
-        ratatui::text::Line::from(line_spans)
+        ratatui::text::Line::from(line_spans.into_iter().collect::<Vec<_>>())
       })
       .collect();
 
@@ -426,8 +418,8 @@ pub fn draw_yaml_block<B: Backend>(f: &mut Frame<'_, B>, app: &App, area: Rect,
 }
 
 /// Draw a kubernetes resource overview tab
-pub fn draw_resource_block<'a, B, T: KubeResource<U>, F, U: Serialize>(
-  f: &mut Frame<'_, B>,
+pub fn draw_resource_block<'a, T: KubeResource<U>, F, U: Serialize>(
+  f: &mut Frame<'_>,
   area: Rect,
   table_props: ResourceTableProps<'a, T>,
   row_cell_mapper: F,
@@ -435,7 +427,6 @@ pub fn draw_resource_block<'a, B, T: KubeResource<U>, F, U: Serialize>(
   is_loading: bool,
   filter: Option<String>,
 ) where
-  B: Backend,
   F: Fn(&T) -> Row<'a>,
 {
   let title = title_with_dual_style(table_props.title, table_props.inline_help, light_theme);
@@ -452,12 +443,11 @@ pub fn draw_resource_block<'a, B, T: KubeResource<U>, F, U: Serialize>(
       }
     });
 
-    let table = Table::new(rows)
+    let table = Table::new(rows, &table_props.column_widths)
       .header(table_header_style(table_props.table_headers, light_theme))
       .block(block)
       .highlight_style(style_highlight())
-      .highlight_symbol(HIGHLIGHT)
-      .widths(&table_props.column_widths);
+      .highlight_symbol(HIGHLIGHT);
 
     f.render_stateful_widget(table, area, &mut table_props.resource.state);
   } else {
